OC.L10N.register(
    "lib",
    {
    "Files" : "ھۆججەتلەر",
    "today" : "بۈگۈن",
    "yesterday" : "تۈنۈگۈن",
    "__language_name__" : "ئۇيغۇرچە",
    "Help" : "ياردەم",
    "Apps" : "ئەپلەر",
    "Settings" : "تەڭشەكلەر",
    "Log out" : "تىزىمدىن چىق",
    "Users" : "ئىشلەتكۈچىلەر",
    "Email" : "تورخەت",
    "Phone" : "تېلېفون",
    "Address" : "ئادرېس",
    "Sunday" : "يەكشەنبە",
    "Monday" : "دۈشەنبە",
    "Tuesday" : "سەيشەنبە",
    "Wednesday" : "چارشەنبە",
    "Thursday" : "پەيشەنبە",
    "Friday" : "جۈمە",
    "Saturday" : "شەنبە",
    "Sun." : "يەك",
    "Mon." : "دۈش",
    "Tue." : "سەي",
    "Wed." : "چار",
    "Thu." : "پەي",
    "Fri." : "جۈم",
    "Sat." : "شەن",
    "January" : "قەھرىتان",
    "February" : "ھۇت",
    "March" : "نەۋرۇز",
    "April" : "ئۇمۇت",
    "May" : "باھار",
    "June" : "سەپەر",
    "July" : "چىللە",
    "August" : "تومۇز",
    "September" : "مىزان",
    "October" : "ئوغۇز",
    "November" : "ئوغلاق",
    "December" : "كۆنەك",
    "Jan." : "قەھرىتان",
    "Feb." : "ھۇت",
    "Mar." : "نەۋرۇز",
    "Apr." : "ئۇمۇت",
    "May." : "باھار",
    "Jun." : "سەپەر",
    "Jul." : "چىللە",
    "Aug." : "تومۇز",
    "Sep." : "مىزان",
    "Oct." : "ئوغۇز",
    "Nov." : "ئوغلاق",
    "Dec." : "كۆنەك",
    "A valid password must be provided" : "چوقۇم ئىناۋەتلىك ئىم تەمىنلەش كېرەك",
    "Authentication error" : "سالاھىيەت دەلىللەش خاتالىقى",
    "A valid username must be provided" : "چوقۇم ئىناۋەتلىك ئىشلەتكۈچى ئىسمىدىن بىرنى تەمىنلەش كېرەك"
},
"nplurals=2; plural=(n != 1);");
